macro_rules! test_primefield {
($fe:tt, $uint:ident) => { ... };
}Expand description
Implement all tests for a type which impls the PrimeField trait.
macro_rules! test_primefield {
($fe:tt, $uint:ident) => { ... };
}Implement all tests for a type which impls the PrimeField trait.