pub struct MontyFieldElement<MOD, const LIMBS: usize>where
MOD: MontyFieldParams<LIMBS>,{
inner: ConstMontyForm<MOD, LIMBS>,
}Expand description
Field element type which uses an internal Montgomery form representation.
Fields
inner: ConstMontyForm<MOD, LIMBS>Implementations
Sourceimpl<MOD, const LIMBS: usize> MontyFieldElement<MOD, LIMBS>where
MOD: MontyFieldParams<LIMBS>,
impl<MOD, const LIMBS: usize> MontyFieldElement<MOD, LIMBS>where
MOD: MontyFieldParams<LIMBS>,
Sourcepub fn from_bytes(repr: &MontyFieldBytes<MOD, LIMBS>) -> CtOption<Self>where
Uint<LIMBS>: ArrayEncoding,
pub fn from_bytes(repr: &MontyFieldBytes<MOD, LIMBS>) -> CtOption<Self>where
Uint<LIMBS>: ArrayEncoding,
Decode field element from a canonical bytestring representation.
Sourcepub fn from_slice(slice: &[u8]) -> Option<Self>where
Uint<LIMBS>: ArrayEncoding,
pub fn from_slice(slice: &[u8]) -> Option<Self>where
Uint<LIMBS>: ArrayEncoding,
Decode field element from a canonical byte slice.
Slice is expected to be zero padded to the expected byte size.
Sourcepub const fn from_hex_vartime(hex: &str) -> Self
pub const fn from_hex_vartime(hex: &str) -> Self
Decode a field element from hex-encoded bytes.
This is primarily intended for defining constants using hex literals.
Panics
- When hex is malformed
- When input is the wrong length
- If input overflows the modulus
Sourcepub const fn from_uint_reduced(uint: &Uint<LIMBS>) -> Self
pub const fn from_uint_reduced(uint: &Uint<LIMBS>) -> Self
Convert Uint into MontyFieldElement, first converting it into Montgomery form:
w * R^2 * R^-1 mod p = wR mod pReduces the input modulo p.
Sourcepub fn from_uint(uint: &Uint<LIMBS>) -> CtOption<Self>
pub fn from_uint(uint: &Uint<LIMBS>) -> CtOption<Self>
Convert Uint into MontyFieldElement, first converting it into Montgomery form:
w * R^2 * R^-1 mod p = wR mod pReturns
The CtOption equivalent of None if the input overflows the modulus.
Sourcepub const fn from_montgomery(uint: Uint<LIMBS>) -> Self
pub const fn from_montgomery(uint: Uint<LIMBS>) -> Self
Create MontyFieldElement from a Uint which is already in Montgomery form.
⚠️ Warning
This value is expected to be in Montgomery form and reduced. Failure to maintain these invariants will lead to miscomputation and potential security issues!
Sourcepub const fn from_montgomery_words(words: [Word; LIMBS]) -> Self
pub const fn from_montgomery_words(words: [Word; LIMBS]) -> Self
Helper function to construct MontyFieldElement from words in Montgomery form.
Sourcepub const fn as_montgomery(&self) -> &Uint<LIMBS>
pub const fn as_montgomery(&self) -> &Uint<LIMBS>
Borrow the inner Uint type which is in Montgomery form.
⚠️ Warning
Make sure you are actually expecting a value in Montgomery form! This is not the correct
function for converting out of Montgomery form: that would be
MontyFieldElement::to_canonical.
Sourcepub const fn to_montgomery_words(&self) -> [Word; LIMBS]
pub const fn to_montgomery_words(&self) -> [Word; LIMBS]
Retrieve the Montgomery form representation as an array of Words.
Sourcepub fn to_bytes(self) -> MontyFieldBytes<MOD, LIMBS>
pub fn to_bytes(self) -> MontyFieldBytes<MOD, LIMBS>
Returns the bytestring encoding of this field element.
Sourcepub fn is_odd(&self) -> Choice
pub fn is_odd(&self) -> Choice
Determine if this field element is odd: self mod 2 == 1.
Returns
If odd, return Choice(1). Otherwise, return Choice(0).
Sourcepub fn is_even(&self) -> Choice
pub fn is_even(&self) -> Choice
Determine if this field element is even: self mod 2 == 0.
Returns
If even, return Choice(1). Otherwise, return Choice(0).
Sourcepub fn is_zero(&self) -> Choice
pub fn is_zero(&self) -> Choice
Determine if this field element is zero.
Returns
If zero, return Choice(1). Otherwise, return Choice(0).
Sourcepub const fn to_canonical(self) -> Uint<LIMBS>
pub const fn to_canonical(self) -> Uint<LIMBS>
Translate field element out of the Montgomery domain, returning a Uint in canonical form.
Sourcepub fn invert_vartime(&self) -> CtOption<Self>
pub fn invert_vartime(&self) -> CtOption<Self>
Compute field inversion: 1 / self in variable-time.
Sourcepub const fn const_invert(&self) -> Self
pub const fn const_invert(&self) -> Self
Compute field inversion as a const fn. Panics if self is zero.
This is mainly intended for inverting constants at compile time.
Sourcepub const fn pow_vartime<const RHS_LIMBS: usize>(
&self,
exp: &Uint<RHS_LIMBS>,
) -> Self
pub const fn pow_vartime<const RHS_LIMBS: usize>( &self, exp: &Uint<RHS_LIMBS>, ) -> Self
Returns self^exp, where exp is a little-endian integer exponent.
This operation is variable time with respect to the exponent exp.
If exp is fixed, this operation is constant time. Note that exp will still be branched
upon and should NOT be a secret.
Sourcepub const fn sqn_vartime(&self, n: usize) -> Self
pub const fn sqn_vartime(&self, n: usize) -> Self
Returns self^(2^n) mod p.
This operation is variable time with respect to the exponent n.
If the exponent is fixed, this operation is constant time.