macro_rules! monty_field_element {
(
name: $fe:tt,
params: $params:ty,
uint: $uint:path,
doc: $doc:expr
) => { ... };
}Expand description
Implements a field element type whose internal representation is in
Montgomery form, providing a combination of trait impls and inherent impls
which are const fn where possible.
Accepts a set of const fn arithmetic operation functions as arguments.
Inherent impls
const ZERO: Selfconst ONE: Self(multiplicative identity)pub fn from_bytespub fn from_slicepub fn from_uintfn from_uint_uncheckedpub fn to_bytespub fn to_canonicalpub fn is_oddpub fn is_zeropub fn double
Trait impls
ConditionallySelectableConstantTimeEqConstantTimeGreaterConstantTimeLessCtEqCtSelectDefaultDefaultIsZeroesEqFieldPartialEqRetrieve
Ops
AddAddAssignSubSubAssignMulMulAssignNegInvert